<?php
/*
 * (c) Logiless Inc.
 */

namespace Plugin\Logiless\Controller;

use Eccube\Application;
use Eccube\Entity\Master\OrderStatus;
use Eccube\Entity\Order;
use Plugin\Logiless\Dao\OrderDao;
use Plugin\Logiless\E2V\OrderE2V;
use Plugin\Logiless\Exception\LogilessException;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Class OrdersController
 * @package Plugin\Logiless\Controller
 */
class OrdersController extends AbstractController
{
    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     * @throws LogilessException
     */
    protected function process(Application $app, Request $request)
    {
        switch ($request->getMethod()) {
            case Request::METHOD_GET:
                return $this->get($app, $request);

            case Request::METHOD_PATCH:
                return $this->patch($app, $request);

            default:
                throw new NotFoundHttpException();
        }
    }

    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     */
    protected function get(Application $app, Request $request)
    {
        $dao = new OrderDao($app);

        return $this->createResponse(OrderE2V::convert($dao->getOrders($request)));
    }

    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     * @throws LogilessException
     */
    protected function patch(Application $app, Request $request)
    {
        // Requestを確認
        if (is_null($request->get('id'))) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_BAD_REQUEST);
        }

        // JSONデータをパース
        $data = json_decode($request->getContent(), true);

        if (is_null($data)) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_INVALID_JSON_FORMAT);
        }

        // 変更後の値を取得
        if (!isset($data['status'])) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_INVALID_JSON_STRUCTURE);
        }

        $orderStatus = $app['eccube.repository.order_status']->find($data['status']);

        if (!$orderStatus instanceof OrderStatus) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_STATUS_ID_DOES_NOT_EXIST);
        }

        // Processing
        $dao = new OrderDao($app);

        foreach ($dao->getOrders($request) as $order) {
            /* @var $order Order */

            // Changes status
            $app['eccube.service.shopping']->setOrderStatus($order, $data['status']);
            $app['orm.em']->flush($order);
        }

        return $this->createResponse(array());
    }
}
