<?php

namespace Plugin\Logiless\Controller;

use Eccube\Application;
use Eccube\Entity\ProductClass;
use Eccube\Entity\ProductStock;
use Plugin\Logiless\Dao\ProductClassDao;
use Plugin\Logiless\E2V\ProductClassE2V;
use Plugin\Logiless\Exception\LogilessException;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Class ProductClassesController
 * @package Plugin\Logiless\Controller
 */
class ProductClassesController extends AbstractController
{
    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     * @throws LogilessException
     */
    protected function process(Application $app, Request $request)
    {
        switch ($request->getMethod()) {
            case Request::METHOD_GET:
                return $this->get($app, $request);

            case Request::METHOD_PATCH:
                return $this->patch($app, $request);

            default:
                throw new NotFoundHttpException();
        }
    }

    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     */
    protected function get(Application $app, Request $request)
    {
        $dao = new ProductClassDao($app);

        return $this->createResponse(ProductClassE2V::convert($dao->getProductClasses($request)));
    }

    /**
     * @param Application $app
     * @param Request $request
     *
     * @return JsonResponse
     * @throws LogilessException
     */
    protected function patch(Application $app, Request $request)
    {
        $data = json_decode($request->getContent(), true);

        if (is_null($data)) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_INVALID_JSON_FORMAT);
        }

        if (!isset($data['product_classes'])) {
            throw LogilessException::onBadRequest(LogilessException::ERROR_INVALID_JSON_STRUCTURE);
        }

        // Entity manager
        $em = $app['orm.em'];

        // Processing
        $dao = new ProductClassDao($app);

        foreach ($data['product_classes'] as $productClassData) {
            if (!isset($productClassData['code']) || !isset($productClassData['stock'])) {
                throw LogilessException::onBadRequest(LogilessException::ERROR_INVALID_JSON_STRUCTURE);
            }

            foreach ($dao->getProductClassesByCode($productClassData['code']) as $productClass) {
                /* @var $productClass ProductClass */

                // 在庫情報の在庫数を更新
                $productStock = $em
                    ->getRepository('Eccube\Entity\ProductStock')
                    ->find($productClass->getProductStock()->getId());

                if ($productStock instanceof ProductStock) {
                    $productStock->setStock($productClassData['stock']);
                }

                // 商品規格情報の在庫数を更新
                $productClass->setStock($productClassData['stock']);

                $app['orm.em']->flush($productStock);
                $app['orm.em']->flush($productClass);
            }
        }

        return $this->createResponse(array());
    }
}
