<?php
/*
 * (c) Logiless Inc.
 */

namespace Plugin\Logiless\Dao;

use Doctrine\ORM\QueryBuilder;
use Eccube\Application;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class AbstractDao
 * @package Plugin\Logiless\Dao
 */
abstract class AbstractDao
{
    /**
     * @var Application
     */
    protected $app;

    /**
     * AbstractDao constructor.
     *
     * @param Application $app
     */
    public function __construct(Application $app)
    {
        $this->app = $app;
    }

    /**
     * @param QueryBuilder $qb
     * @param Request $request
     */
    protected function paging(QueryBuilder $qb, Request $request)
    {
        $limit = min((int)$request->get('limit', 100), 100);
        $offset = (int)$request->get('offset', 0);

        $qb
            ->setMaxResults($limit)
            ->setFirstResult($offset);
    }

    /**
     * @param Request $request
     * @param array $criteria
     *
     * @return array
     */
    protected static function buildCriteria(Request $request, array $criteria)
    {
        foreach ($criteria as $property => $default) {
            $requested = $request->get($property, $default);

            if (!is_array($requested)) {
                $requested = trim($requested);
            }

            if ('0' === $requested || $requested) {
                $criteria[$property] = $requested;
            }
        }

        return $criteria;
    }
}