<?php
/*
 * (c) Logiless Inc.
 */

namespace Plugin\Logiless\Dao;

use Doctrine\ORM\QueryBuilder;
use Eccube\Entity\Order;
use Eccube\Entity\Product;
use Eccube\Entity\ProductClass;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class ProductClassDao
 * @package Plugin\Logiless\Dao
 */
class ProductClassDao extends AbstractDao
{
    /**
     * 商品情報を取得
     *
     * @param Request $request
     *
     * @return ProductClass[]
     */
    public function getProductClasses(Request $request)
    {
        // 受注情報の取得
        $qb = $this->app['orm.em']->createQueryBuilder();
        /* @var $qb QueryBuilder */

        $qb
            ->select('pc')
            ->from('Eccube\Entity\ProductClass', 'pc')
            ->innerJoin('pc.Product', 'p')
            ->andWhere('pc.del_flg = :pc_del_flg')
            ->setParameter('pc_del_flg', 0)
            ->orderBy('pc.id', 'DESC');

        $criteria = static::buildCriteria($request, array(
            'code' => null,
        ));

        if (!is_null($criteria['code'])) {
            $codeList = is_array($criteria['code']) ? $criteria['code'] : array($criteria['code']);

            $qb
                ->andWhere('pc.code IN (:code_list)')
                ->setParameter('code_list', $codeList);
        }

        $this->paging($qb, $request);

        return $qb->getQuery()->execute();
    }

    /**
     * 商品情報を取得
     *
     * @param string $code
     *
     * @return ProductClass[]
     */
    public function getProductClassesByCode($code)
    {
        // 受注情報の取得
        $qb = $this->app['orm.em']->createQueryBuilder();
        /* @var $qb QueryBuilder */

        $qb
            ->select('pc')
            ->from('Eccube\Entity\ProductClass', 'pc')
            ->innerJoin('pc.Product', 'p')
            ->andWhere('pc.del_flg = :pc_del_flg')
            ->setParameter('pc_del_flg', 0)
            ->andWhere('pc.code = :code')
            ->setParameter('code', $code)
            ->orderBy('pc.id', 'DESC');

        return $qb->getQuery()->execute();
    }
}